/* ReadyWatcher.c generated by valac 0.56.13, the Vala compiler
 * generated from ReadyWatcher.vala, do not modify */

/* -*- Mode: Vala; indent-tabs-mode: nil; tab-width: 2 -*-
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 * SPDX-FileCopyrightText: Michael Terry
 */
/* This class does three main things, all centered around "readiness".*/
/* "Readiness" is whether we could/should start a backup now. For example,*/
/* the network is up and unmetered. We're not in low power mode. The external*/
/* drive is plugged in. That sort of thing.*/
/**/
/* 1) Watching for possible readiness changes*/
/**/
/* This class watches all the various possible tiggers that might change our*/
/* "ready" state and signals that something changed.*/
/**/
/* This class is intentionally a little dumb. It doesn't know what the policy*/
/* is, whether we are even scheduled for a backup right now, what storage*/
/* location is even configured, etc. It just messages if any possible trigger*/
/* for any storage location or possible backup changed. Then the policy*/
/* driver (the main monitor process) will decide what to do.*/
/**/
/* 2) Actually checking readiness*/
/**/
/* This class also holds the `is_ready` method, which the main monitor process*/
/* may use as part of deciding what to do - but we don't call it ourselves*/
/* prematurely, because it has side effects (like mounting) that we only want*/
/* to initiate if it's time for a backup.*/
/**/
/* 3) Keeping track of "not yet ready" reasons*/
/**/
/* In a given "waiting to become ready" cycle (which in practice is a day, as*/
/* that is how long Scheduler will wait on its own to backup again), we keep*/
/* track of the various reasons we weren't ready yet. We do this because we*/
/* don't want to keep nagging the user to plug in their external drive.*/
/**/
/* And we also want to make sure that if a new not-yet-ready reason appears,*/
/* that we do actually bug the user about it. For example, if we say "we need*/
/* to be connected to the internet please" and they do, but it's a metered*/
/* connection - we need to tell the user about _that_ now (while not bothering*/
/* them about connecting to internet for the rest of the day).*/

#include <glib-object.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <glib/gi18n-lib.h>
#include "deja.h"

#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TYPE_READY_WATCHER (ready_watcher_get_type ())
#define READY_WATCHER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_READY_WATCHER, ReadyWatcher))
#define READY_WATCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_READY_WATCHER, ReadyWatcherClass))
#define IS_READY_WATCHER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_READY_WATCHER))
#define IS_READY_WATCHER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_READY_WATCHER))
#define READY_WATCHER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_READY_WATCHER, ReadyWatcherClass))

typedef struct _ReadyWatcher ReadyWatcher;
typedef struct _ReadyWatcherClass ReadyWatcherClass;
typedef struct _ReadyWatcherPrivate ReadyWatcherPrivate;

#define TYPE_GAME_MODE (game_mode_get_type ())
#define GAME_MODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GAME_MODE, GameMode))
#define GAME_MODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GAME_MODE, GameModeClass))
#define IS_GAME_MODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GAME_MODE))
#define IS_GAME_MODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GAME_MODE))
#define GAME_MODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GAME_MODE, GameModeClass))

typedef struct _GameMode GameMode;
typedef struct _GameModeClass GameModeClass;
enum  {
	READY_WATCHER_0_PROPERTY,
	READY_WATCHER_NO_DELAY_PROPERTY,
	READY_WATCHER_NUM_PROPERTIES
};
static GParamSpec* ready_watcher_properties[READY_WATCHER_NUM_PROPERTIES];
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _ReadyWatcherIsReadyData ReadyWatcherIsReadyData;
typedef struct _ReadyWatcherIsReadyWithReasonData ReadyWatcherIsReadyWithReasonData;
enum  {
	READY_WATCHER_MAYBE_READY_SIGNAL,
	READY_WATCHER_STOP_AUTO_SIGNAL,
	READY_WATCHER_NUM_SIGNALS
};
static guint ready_watcher_signals[READY_WATCHER_NUM_SIGNALS] = {0};

struct _ReadyWatcher {
	GObject parent_instance;
	ReadyWatcherPrivate * priv;
};

struct _ReadyWatcherClass {
	GObjectClass parent_class;
};

struct _ReadyWatcherPrivate {
	gboolean _no_delay;
	guint netcheck_id;
	GHashTable* unready_reasons;
	GameMode* gamemode;
	GPowerProfileMonitor* power_monitor;
};

struct _ReadyWatcherIsReadyData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	ReadyWatcher* self;
	gint days_late;
	gchar* message;
	gboolean result;
	gchar* reason;
	gchar* reason_message;
	gboolean ready;
	gchar* _tmp0_;
	gchar* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	gboolean _tmp4_;
	const gchar* _tmp5_;
	GHashTable* _tmp6_;
	const gchar* _tmp7_;
	GHashTable* _tmp8_;
	const gchar* _tmp9_;
	gchar* _tmp10_;
	gchar** parts;
	const gchar* _tmp11_;
	gchar** _tmp12_;
	gchar** _tmp13_;
	gint parts_length1;
	gint _parts_size_;
	gchar** _tmp14_;
	gint _tmp14__length1;
	GHashTable* _tmp15_;
	gchar** _tmp16_;
	gint _tmp16__length1;
	const gchar* _tmp17_;
	gchar* _tmp18_;
	const gchar* _tmp19_;
	gchar* _tmp20_;
	gboolean _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
};

struct _ReadyWatcherIsReadyWithReasonData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GTask* _async_result;
	ReadyWatcher* self;
	gint days_late;
	gchar* reason;
	gchar* message;
	gboolean result;
	GameMode* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	gchar* _tmp3_;
	GPowerProfileMonitor* _tmp4_;
	gboolean _tmp5_;
	gboolean _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	DejaDupBackend* backend;
	DejaDupBackend* _tmp10_;
	DejaDupNetwork* network;
	DejaDupNetwork* _tmp11_;
	gboolean _tmp12_;
	DejaDupBackend* _tmp13_;
	DejaDupNetwork* _tmp14_;
	gboolean _tmp15_;
	gboolean _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gboolean _tmp19_;
	DejaDupBackend* _tmp20_;
	DejaDupNetwork* _tmp21_;
	gboolean _tmp22_;
	gboolean _tmp23_;
	gchar* _tmp24_;
	gchar* _tmp25_;
	DejaDupBackend* _tmp26_;
	gchar* _tmp27_;
	gchar* _tmp28_;
	gboolean _tmp29_;
};

static gint ReadyWatcher_private_offset;
static gpointer ready_watcher_parent_class = NULL;

VALA_EXTERN GType ready_watcher_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (ReadyWatcher, g_object_unref)
VALA_EXTERN GType game_mode_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (GameMode, g_object_unref)
VALA_EXTERN ReadyWatcher* ready_watcher_new (gboolean no_delay);
VALA_EXTERN ReadyWatcher* ready_watcher_construct (GType object_type,
                                       gboolean no_delay);
static void ready_watcher_is_ready_data_free (gpointer _data);
VALA_EXTERN void ready_watcher_is_ready (ReadyWatcher* self,
                             gint days_late,
                             GAsyncReadyCallback _callback_,
                             gpointer _user_data_);
VALA_EXTERN gboolean ready_watcher_is_ready_finish (ReadyWatcher* self,
                                        GAsyncResult* _res_,
                                        gchar** message);
static gboolean ready_watcher_is_ready_co (ReadyWatcherIsReadyData* _data_);
static void ready_watcher_is_ready_with_reason (ReadyWatcher* self,
                                         gint days_late,
                                         GAsyncReadyCallback _callback_,
                                         gpointer _user_data_);
static gboolean ready_watcher_is_ready_with_reason_finish (ReadyWatcher* self,
                                                    GAsyncResult* _res_,
                                                    gchar** reason,
                                                    gchar** message);
static void ready_watcher_is_ready_ready (GObject* source_object,
                                   GAsyncResult* _res_,
                                   gpointer _user_data_);
VALA_EXTERN void ready_watcher_reset_reasons (ReadyWatcher* self);
static void _g_free0_ (gpointer var);
static void ready_watcher_is_ready_with_reason_data_free (gpointer _data);
static gboolean ready_watcher_is_ready_with_reason_co (ReadyWatcherIsReadyWithReasonData* _data_);
VALA_EXTERN gboolean game_mode_get_enabled (GameMode* self);
static void ready_watcher_is_ready_with_reason_ready (GObject* source_object,
                                               GAsyncResult* _res_,
                                               gpointer _user_data_);
static void ready_watcher_volume_added (ReadyWatcher* self);
static void ready_watcher_gamemode_changed (ReadyWatcher* self);
static void ready_watcher_power_saver_changed (ReadyWatcher* self);
static void ready_watcher_network_changed (ReadyWatcher* self);
VALA_EXTERN gboolean ready_watcher_get_no_delay (ReadyWatcher* self);
static gboolean __lambda6_ (ReadyWatcher* self);
static gboolean ___lambda6__gsource_func (gpointer self);
VALA_EXTERN void ready_watcher_set_no_delay (ReadyWatcher* self,
                                 gboolean value);
static GObject * ready_watcher_constructor (GType type,
                                     guint n_construct_properties,
                                     GObjectConstructParam * construct_properties);
static void _ready_watcher_network_changed_g_object_notify (GObject* _sender,
                                                     GParamSpec* pspec,
                                                     gpointer self);
static void _ready_watcher_volume_added_g_volume_monitor_volume_added (GVolumeMonitor* _sender,
                                                                GVolume* volume,
                                                                gpointer self);
VALA_EXTERN GameMode* game_mode_new (void);
VALA_EXTERN GameMode* game_mode_construct (GType object_type);
static void _ready_watcher_gamemode_changed_g_object_notify (GObject* _sender,
                                                      GParamSpec* pspec,
                                                      gpointer self);
static void _ready_watcher_power_saver_changed_g_object_notify (GObject* _sender,
                                                         GParamSpec* pspec,
                                                         gpointer self);
static void ready_watcher_finalize (GObject * obj);
static GType ready_watcher_get_type_once (void);
static void _vala_ready_watcher_get_property (GObject * object,
                                       guint property_id,
                                       GValue * value,
                                       GParamSpec * pspec);
static void _vala_ready_watcher_set_property (GObject * object,
                                       guint property_id,
                                       const GValue * value,
                                       GParamSpec * pspec);
static void _vala_array_destroy (gpointer array,
                          gssize array_length,
                          GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array,
                       gssize array_length,
                       GDestroyNotify destroy_func);
static gssize _vala_array_length (gpointer array);

static inline gpointer
ready_watcher_get_instance_private (ReadyWatcher* self)
{
	return G_STRUCT_MEMBER_P (self, ReadyWatcher_private_offset);
}

ReadyWatcher*
ready_watcher_construct (GType object_type,
                         gboolean no_delay)
{
	ReadyWatcher * self = NULL;
#line 57 "../monitor/ReadyWatcher.vala"
	self = (ReadyWatcher*) g_object_new (object_type, "no-delay", no_delay, NULL);
#line 55 "../monitor/ReadyWatcher.vala"
	return self;
#line 303 "ReadyWatcher.c"
}

ReadyWatcher*
ready_watcher_new (gboolean no_delay)
{
#line 55 "../monitor/ReadyWatcher.vala"
	return ready_watcher_construct (TYPE_READY_WATCHER, no_delay);
#line 311 "ReadyWatcher.c"
}

static void
ready_watcher_is_ready_data_free (gpointer _data)
{
	ReadyWatcherIsReadyData* _data_;
	_data_ = _data;
#line 45 "../monitor/ReadyWatcher.vala"
	_g_object_unref0 (_data_->self);
#line 45 "../monitor/ReadyWatcher.vala"
	g_slice_free (ReadyWatcherIsReadyData, _data_);
#line 323 "ReadyWatcher.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 45 "../monitor/ReadyWatcher.vala"
	return self ? g_object_ref (self) : NULL;
#line 331 "ReadyWatcher.c"
}

void
ready_watcher_is_ready (ReadyWatcher* self,
                        gint days_late,
                        GAsyncReadyCallback _callback_,
                        gpointer _user_data_)
{
	ReadyWatcherIsReadyData* _data_;
	ReadyWatcher* _tmp0_;
#line 45 "../monitor/ReadyWatcher.vala"
	g_return_if_fail (self != NULL);
#line 45 "../monitor/ReadyWatcher.vala"
	_data_ = g_slice_new0 (ReadyWatcherIsReadyData);
#line 45 "../monitor/ReadyWatcher.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 45 "../monitor/ReadyWatcher.vala"
	g_task_set_task_data (_data_->_async_result, _data_, ready_watcher_is_ready_data_free);
#line 45 "../monitor/ReadyWatcher.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 45 "../monitor/ReadyWatcher.vala"
	_data_->self = _tmp0_;
#line 45 "../monitor/ReadyWatcher.vala"
	_data_->days_late = days_late;
#line 45 "../monitor/ReadyWatcher.vala"
	ready_watcher_is_ready_co (_data_);
#line 358 "ReadyWatcher.c"
}

gboolean
ready_watcher_is_ready_finish (ReadyWatcher* self,
                               GAsyncResult* _res_,
                               gchar** message)
{
	gboolean result;
	ReadyWatcherIsReadyData* _data_;
#line 45 "../monitor/ReadyWatcher.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 45 "../monitor/ReadyWatcher.vala"
	if (message) {
#line 45 "../monitor/ReadyWatcher.vala"
		*message = _data_->message;
#line 374 "ReadyWatcher.c"
	} else {
#line 45 "../monitor/ReadyWatcher.vala"
		_g_free0 (_data_->message);
#line 378 "ReadyWatcher.c"
	}
#line 45 "../monitor/ReadyWatcher.vala"
	_data_->message = NULL;
#line 45 "../monitor/ReadyWatcher.vala"
	result = _data_->result;
#line 45 "../monitor/ReadyWatcher.vala"
	return result;
#line 386 "ReadyWatcher.c"
}

static void
ready_watcher_is_ready_ready (GObject* source_object,
                              GAsyncResult* _res_,
                              gpointer _user_data_)
{
	ReadyWatcherIsReadyData* _data_;
#line 65 "../monitor/ReadyWatcher.vala"
	_data_ = _user_data_;
#line 65 "../monitor/ReadyWatcher.vala"
	_data_->_source_object_ = source_object;
#line 65 "../monitor/ReadyWatcher.vala"
	_data_->_res_ = _res_;
#line 65 "../monitor/ReadyWatcher.vala"
	ready_watcher_is_ready_co (_data_);
#line 403 "ReadyWatcher.c"
}

static gboolean
ready_watcher_is_ready_co (ReadyWatcherIsReadyData* _data_)
{
#line 60 "../monitor/ReadyWatcher.vala"
	switch (_data_->_state_) {
#line 60 "../monitor/ReadyWatcher.vala"
		case 0:
#line 413 "ReadyWatcher.c"
		goto _state_0;
#line 60 "../monitor/ReadyWatcher.vala"
		case 1:
#line 417 "ReadyWatcher.c"
		goto _state_1;
		default:
#line 60 "../monitor/ReadyWatcher.vala"
		g_assert_not_reached ();
#line 422 "ReadyWatcher.c"
	}
	_state_0:
#line 62 "../monitor/ReadyWatcher.vala"
	_g_free0 (_data_->message);
#line 62 "../monitor/ReadyWatcher.vala"
	_data_->message = NULL;
#line 65 "../monitor/ReadyWatcher.vala"
	_data_->_tmp0_ = NULL;
#line 65 "../monitor/ReadyWatcher.vala"
	_data_->_tmp1_ = NULL;
#line 65 "../monitor/ReadyWatcher.vala"
	_data_->_state_ = 1;
#line 65 "../monitor/ReadyWatcher.vala"
	ready_watcher_is_ready_with_reason (_data_->self, _data_->days_late, ready_watcher_is_ready_ready, _data_);
#line 65 "../monitor/ReadyWatcher.vala"
	return FALSE;
#line 439 "ReadyWatcher.c"
	_state_1:
#line 65 "../monitor/ReadyWatcher.vala"
	_data_->_tmp2_ = ready_watcher_is_ready_with_reason_finish (_data_->self, _data_->_res_, &_data_->_tmp0_, &_data_->_tmp1_);
#line 65 "../monitor/ReadyWatcher.vala"
	_g_free0 (_data_->reason);
#line 65 "../monitor/ReadyWatcher.vala"
	_data_->reason = _data_->_tmp0_;
#line 65 "../monitor/ReadyWatcher.vala"
	_g_free0 (_data_->reason_message);
#line 65 "../monitor/ReadyWatcher.vala"
	_data_->reason_message = _data_->_tmp1_;
#line 65 "../monitor/ReadyWatcher.vala"
	_data_->ready = _data_->_tmp2_;
#line 67 "../monitor/ReadyWatcher.vala"
	if (!_data_->ready) {
#line 67 "../monitor/ReadyWatcher.vala"
		_data_->_tmp5_ = _data_->reason;
#line 67 "../monitor/ReadyWatcher.vala"
		_data_->_tmp4_ = _data_->_tmp5_ != NULL;
#line 459 "ReadyWatcher.c"
	} else {
#line 67 "../monitor/ReadyWatcher.vala"
		_data_->_tmp4_ = FALSE;
#line 463 "ReadyWatcher.c"
	}
#line 67 "../monitor/ReadyWatcher.vala"
	if (_data_->_tmp4_) {
#line 67 "../monitor/ReadyWatcher.vala"
		_data_->_tmp6_ = _data_->self->priv->unready_reasons;
#line 67 "../monitor/ReadyWatcher.vala"
		_data_->_tmp7_ = _data_->reason;
#line 67 "../monitor/ReadyWatcher.vala"
		_data_->_tmp3_ = !g_hash_table_contains (_data_->_tmp6_, _data_->_tmp7_);
#line 473 "ReadyWatcher.c"
	} else {
#line 67 "../monitor/ReadyWatcher.vala"
		_data_->_tmp3_ = FALSE;
#line 477 "ReadyWatcher.c"
	}
#line 67 "../monitor/ReadyWatcher.vala"
	if (_data_->_tmp3_) {
#line 69 "../monitor/ReadyWatcher.vala"
		_data_->_tmp8_ = _data_->self->priv->unready_reasons;
#line 69 "../monitor/ReadyWatcher.vala"
		_data_->_tmp9_ = _data_->reason;
#line 69 "../monitor/ReadyWatcher.vala"
		_data_->_tmp10_ = g_strdup (_data_->_tmp9_);
#line 69 "../monitor/ReadyWatcher.vala"
		g_hash_table_add (_data_->_tmp8_, _data_->_tmp10_);
#line 72 "../monitor/ReadyWatcher.vala"
		_data_->_tmp11_ = _data_->reason;
#line 72 "../monitor/ReadyWatcher.vala"
		_data_->_tmp13_ = _data_->_tmp12_ = g_strsplit (_data_->_tmp11_, ".", 0);
#line 72 "../monitor/ReadyWatcher.vala"
		_data_->parts = _data_->_tmp13_;
#line 72 "../monitor/ReadyWatcher.vala"
		_data_->parts_length1 = _vala_array_length (_data_->_tmp12_);
#line 72 "../monitor/ReadyWatcher.vala"
		_data_->_parts_size_ = _data_->parts_length1;
#line 73 "../monitor/ReadyWatcher.vala"
		_data_->_tmp14_ = _data_->parts;
#line 73 "../monitor/ReadyWatcher.vala"
		_data_->_tmp14__length1 = _data_->parts_length1;
#line 73 "../monitor/ReadyWatcher.vala"
		if (_data_->_tmp14__length1 > 1) {
#line 74 "../monitor/ReadyWatcher.vala"
			_data_->_tmp15_ = _data_->self->priv->unready_reasons;
#line 74 "../monitor/ReadyWatcher.vala"
			_data_->_tmp16_ = _data_->parts;
#line 74 "../monitor/ReadyWatcher.vala"
			_data_->_tmp16__length1 = _data_->parts_length1;
#line 74 "../monitor/ReadyWatcher.vala"
			_data_->_tmp17_ = _data_->_tmp16_[0];
#line 74 "../monitor/ReadyWatcher.vala"
			_data_->_tmp18_ = g_strdup (_data_->_tmp17_);
#line 74 "../monitor/ReadyWatcher.vala"
			g_hash_table_add (_data_->_tmp15_, _data_->_tmp18_);
#line 517 "ReadyWatcher.c"
		}
#line 76 "../monitor/ReadyWatcher.vala"
		_data_->_tmp19_ = _data_->reason_message;
#line 76 "../monitor/ReadyWatcher.vala"
		_data_->_tmp20_ = g_strdup (_data_->_tmp19_);
#line 76 "../monitor/ReadyWatcher.vala"
		_g_free0 (_data_->message);
#line 76 "../monitor/ReadyWatcher.vala"
		_data_->message = _data_->_tmp20_;
#line 67 "../monitor/ReadyWatcher.vala"
		_data_->parts = (_vala_array_free (_data_->parts, _data_->parts_length1, (GDestroyNotify) g_free), NULL);
#line 529 "ReadyWatcher.c"
	}
#line 79 "../monitor/ReadyWatcher.vala"
	if (!_data_->ready) {
#line 79 "../monitor/ReadyWatcher.vala"
		_data_->_tmp22_ = _data_->reason;
#line 79 "../monitor/ReadyWatcher.vala"
		_data_->_tmp21_ = _data_->_tmp22_ != NULL;
#line 537 "ReadyWatcher.c"
	} else {
#line 79 "../monitor/ReadyWatcher.vala"
		_data_->_tmp21_ = FALSE;
#line 541 "ReadyWatcher.c"
	}
#line 79 "../monitor/ReadyWatcher.vala"
	if (_data_->_tmp21_) {
#line 80 "../monitor/ReadyWatcher.vala"
		_data_->_tmp23_ = _data_->reason;
#line 80 "../monitor/ReadyWatcher.vala"
		g_debug ("ReadyWatcher.vala:80: Backup is not ready yet: %s", _data_->_tmp23_);
#line 549 "ReadyWatcher.c"
	}
#line 82 "../monitor/ReadyWatcher.vala"
	_data_->result = _data_->ready;
#line 82 "../monitor/ReadyWatcher.vala"
	_g_free0 (_data_->reason_message);
#line 82 "../monitor/ReadyWatcher.vala"
	_g_free0 (_data_->reason);
#line 82 "../monitor/ReadyWatcher.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 82 "../monitor/ReadyWatcher.vala"
	if (_data_->_state_ != 0) {
#line 82 "../monitor/ReadyWatcher.vala"
		while (!g_task_get_completed (_data_->_async_result)) {
#line 82 "../monitor/ReadyWatcher.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 565 "ReadyWatcher.c"
		}
	}
#line 82 "../monitor/ReadyWatcher.vala"
	g_object_unref (_data_->_async_result);
#line 82 "../monitor/ReadyWatcher.vala"
	return FALSE;
#line 572 "ReadyWatcher.c"
}

static void
_g_free0_ (gpointer var)
{
#line 87 "../monitor/ReadyWatcher.vala"
	var = (g_free (var), NULL);
#line 580 "ReadyWatcher.c"
}

void
ready_watcher_reset_reasons (ReadyWatcher* self)
{
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
#line 85 "../monitor/ReadyWatcher.vala"
	g_return_if_fail (self != NULL);
#line 87 "../monitor/ReadyWatcher.vala"
	_tmp0_ = g_str_hash;
#line 87 "../monitor/ReadyWatcher.vala"
	_tmp1_ = g_str_equal;
#line 87 "../monitor/ReadyWatcher.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, NULL, _g_free0_);
#line 87 "../monitor/ReadyWatcher.vala"
	_g_hash_table_unref0 (self->priv->unready_reasons);
#line 87 "../monitor/ReadyWatcher.vala"
	self->priv->unready_reasons = _tmp2_;
#line 601 "ReadyWatcher.c"
}

static void
ready_watcher_is_ready_with_reason_data_free (gpointer _data)
{
	ReadyWatcherIsReadyWithReasonData* _data_;
	_data_ = _data;
#line 45 "../monitor/ReadyWatcher.vala"
	_g_object_unref0 (_data_->self);
#line 45 "../monitor/ReadyWatcher.vala"
	g_slice_free (ReadyWatcherIsReadyWithReasonData, _data_);
#line 613 "ReadyWatcher.c"
}

static void
ready_watcher_is_ready_with_reason (ReadyWatcher* self,
                                    gint days_late,
                                    GAsyncReadyCallback _callback_,
                                    gpointer _user_data_)
{
	ReadyWatcherIsReadyWithReasonData* _data_;
	ReadyWatcher* _tmp0_;
#line 45 "../monitor/ReadyWatcher.vala"
	g_return_if_fail (self != NULL);
#line 45 "../monitor/ReadyWatcher.vala"
	_data_ = g_slice_new0 (ReadyWatcherIsReadyWithReasonData);
#line 45 "../monitor/ReadyWatcher.vala"
	_data_->_async_result = g_task_new (G_OBJECT (self), NULL, _callback_, _user_data_);
#line 45 "../monitor/ReadyWatcher.vala"
	g_task_set_task_data (_data_->_async_result, _data_, ready_watcher_is_ready_with_reason_data_free);
#line 45 "../monitor/ReadyWatcher.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 45 "../monitor/ReadyWatcher.vala"
	_data_->self = _tmp0_;
#line 45 "../monitor/ReadyWatcher.vala"
	_data_->days_late = days_late;
#line 45 "../monitor/ReadyWatcher.vala"
	ready_watcher_is_ready_with_reason_co (_data_);
#line 640 "ReadyWatcher.c"
}

static gboolean
ready_watcher_is_ready_with_reason_finish (ReadyWatcher* self,
                                           GAsyncResult* _res_,
                                           gchar** reason,
                                           gchar** message)
{
	gboolean result;
	ReadyWatcherIsReadyWithReasonData* _data_;
#line 45 "../monitor/ReadyWatcher.vala"
	_data_ = g_task_propagate_pointer (G_TASK (_res_), NULL);
#line 45 "../monitor/ReadyWatcher.vala"
	if (reason) {
#line 45 "../monitor/ReadyWatcher.vala"
		*reason = _data_->reason;
#line 657 "ReadyWatcher.c"
	} else {
#line 45 "../monitor/ReadyWatcher.vala"
		_g_free0 (_data_->reason);
#line 661 "ReadyWatcher.c"
	}
#line 45 "../monitor/ReadyWatcher.vala"
	_data_->reason = NULL;
#line 45 "../monitor/ReadyWatcher.vala"
	if (message) {
#line 45 "../monitor/ReadyWatcher.vala"
		*message = _data_->message;
#line 669 "ReadyWatcher.c"
	} else {
#line 45 "../monitor/ReadyWatcher.vala"
		_g_free0 (_data_->message);
#line 673 "ReadyWatcher.c"
	}
#line 45 "../monitor/ReadyWatcher.vala"
	_data_->message = NULL;
#line 45 "../monitor/ReadyWatcher.vala"
	result = _data_->result;
#line 45 "../monitor/ReadyWatcher.vala"
	return result;
#line 681 "ReadyWatcher.c"
}

static void
ready_watcher_is_ready_with_reason_ready (GObject* source_object,
                                          GAsyncResult* _res_,
                                          gpointer _user_data_)
{
	ReadyWatcherIsReadyWithReasonData* _data_;
#line 169 "../monitor/ReadyWatcher.vala"
	_data_ = _user_data_;
#line 169 "../monitor/ReadyWatcher.vala"
	_data_->_source_object_ = source_object;
#line 169 "../monitor/ReadyWatcher.vala"
	_data_->_res_ = _res_;
#line 169 "../monitor/ReadyWatcher.vala"
	ready_watcher_is_ready_with_reason_co (_data_);
#line 698 "ReadyWatcher.c"
}

static gboolean
ready_watcher_is_ready_with_reason_co (ReadyWatcherIsReadyWithReasonData* _data_)
{
#line 130 "../monitor/ReadyWatcher.vala"
	switch (_data_->_state_) {
#line 130 "../monitor/ReadyWatcher.vala"
		case 0:
#line 708 "ReadyWatcher.c"
		goto _state_0;
#line 130 "../monitor/ReadyWatcher.vala"
		case 1:
#line 712 "ReadyWatcher.c"
		goto _state_1;
		default:
#line 130 "../monitor/ReadyWatcher.vala"
		g_assert_not_reached ();
#line 717 "ReadyWatcher.c"
	}
	_state_0:
#line 132 "../monitor/ReadyWatcher.vala"
	_data_->_tmp0_ = _data_->self->priv->gamemode;
#line 132 "../monitor/ReadyWatcher.vala"
	_data_->_tmp1_ = game_mode_get_enabled (_data_->_tmp0_);
#line 132 "../monitor/ReadyWatcher.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 132 "../monitor/ReadyWatcher.vala"
	if (_data_->_tmp2_) {
#line 133 "../monitor/ReadyWatcher.vala"
		_data_->_tmp3_ = g_strdup ("gamemode");
#line 133 "../monitor/ReadyWatcher.vala"
		_g_free0 (_data_->reason);
#line 133 "../monitor/ReadyWatcher.vala"
		_data_->reason = _data_->_tmp3_;
#line 134 "../monitor/ReadyWatcher.vala"
		_g_free0 (_data_->message);
#line 134 "../monitor/ReadyWatcher.vala"
		_data_->message = NULL;
#line 135 "../monitor/ReadyWatcher.vala"
		_data_->result = FALSE;
#line 135 "../monitor/ReadyWatcher.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 135 "../monitor/ReadyWatcher.vala"
		if (_data_->_state_ != 0) {
#line 135 "../monitor/ReadyWatcher.vala"
			while (!g_task_get_completed (_data_->_async_result)) {
#line 135 "../monitor/ReadyWatcher.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 748 "ReadyWatcher.c"
			}
		}
#line 135 "../monitor/ReadyWatcher.vala"
		g_object_unref (_data_->_async_result);
#line 135 "../monitor/ReadyWatcher.vala"
		return FALSE;
#line 755 "ReadyWatcher.c"
	}
#line 138 "../monitor/ReadyWatcher.vala"
	_data_->_tmp4_ = _data_->self->priv->power_monitor;
#line 138 "../monitor/ReadyWatcher.vala"
	_data_->_tmp5_ = g_power_profile_monitor_get_power_saver_enabled (_data_->_tmp4_);
#line 138 "../monitor/ReadyWatcher.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 138 "../monitor/ReadyWatcher.vala"
	if (_data_->_tmp6_) {
#line 146 "../monitor/ReadyWatcher.vala"
		if (_data_->days_late < 1) {
#line 147 "../monitor/ReadyWatcher.vala"
			_data_->_tmp7_ = g_strdup ("power-saver");
#line 147 "../monitor/ReadyWatcher.vala"
			_g_free0 (_data_->reason);
#line 147 "../monitor/ReadyWatcher.vala"
			_data_->reason = _data_->_tmp7_;
#line 148 "../monitor/ReadyWatcher.vala"
			_g_free0 (_data_->message);
#line 148 "../monitor/ReadyWatcher.vala"
			_data_->message = NULL;
#line 777 "ReadyWatcher.c"
		} else {
#line 150 "../monitor/ReadyWatcher.vala"
			_data_->_tmp8_ = g_strdup ("power-saver.overdue");
#line 150 "../monitor/ReadyWatcher.vala"
			_g_free0 (_data_->reason);
#line 150 "../monitor/ReadyWatcher.vala"
			_data_->reason = _data_->_tmp8_;
#line 151 "../monitor/ReadyWatcher.vala"
			_data_->_tmp9_ = g_strdup (_ ("Backup will begin when power saver mode is no longer active."));
#line 151 "../monitor/ReadyWatcher.vala"
			_g_free0 (_data_->message);
#line 151 "../monitor/ReadyWatcher.vala"
			_data_->message = _data_->_tmp9_;
#line 791 "ReadyWatcher.c"
		}
#line 153 "../monitor/ReadyWatcher.vala"
		_data_->result = FALSE;
#line 153 "../monitor/ReadyWatcher.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 153 "../monitor/ReadyWatcher.vala"
		if (_data_->_state_ != 0) {
#line 153 "../monitor/ReadyWatcher.vala"
			while (!g_task_get_completed (_data_->_async_result)) {
#line 153 "../monitor/ReadyWatcher.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 803 "ReadyWatcher.c"
			}
		}
#line 153 "../monitor/ReadyWatcher.vala"
		g_object_unref (_data_->_async_result);
#line 153 "../monitor/ReadyWatcher.vala"
		return FALSE;
#line 810 "ReadyWatcher.c"
	}
#line 156 "../monitor/ReadyWatcher.vala"
	_data_->_tmp10_ = deja_dup_backend_get_default ();
#line 156 "../monitor/ReadyWatcher.vala"
	_data_->backend = _data_->_tmp10_;
#line 157 "../monitor/ReadyWatcher.vala"
	_data_->_tmp11_ = deja_dup_network_get ();
#line 157 "../monitor/ReadyWatcher.vala"
	_data_->network = _data_->_tmp11_;
#line 158 "../monitor/ReadyWatcher.vala"
	_data_->_tmp13_ = _data_->backend;
#line 158 "../monitor/ReadyWatcher.vala"
	if (!deja_dup_backend_is_native (_data_->_tmp13_)) {
#line 158 "../monitor/ReadyWatcher.vala"
		_data_->_tmp14_ = _data_->network;
#line 158 "../monitor/ReadyWatcher.vala"
		_data_->_tmp15_ = deja_dup_network_get_connected (_data_->_tmp14_);
#line 158 "../monitor/ReadyWatcher.vala"
		_data_->_tmp16_ = _data_->_tmp15_;
#line 158 "../monitor/ReadyWatcher.vala"
		_data_->_tmp12_ = !_data_->_tmp16_;
#line 832 "ReadyWatcher.c"
	} else {
#line 158 "../monitor/ReadyWatcher.vala"
		_data_->_tmp12_ = FALSE;
#line 836 "ReadyWatcher.c"
	}
#line 158 "../monitor/ReadyWatcher.vala"
	if (_data_->_tmp12_) {
#line 159 "../monitor/ReadyWatcher.vala"
		_data_->_tmp17_ = g_strdup ("network-connection");
#line 159 "../monitor/ReadyWatcher.vala"
		_g_free0 (_data_->reason);
#line 159 "../monitor/ReadyWatcher.vala"
		_data_->reason = _data_->_tmp17_;
#line 160 "../monitor/ReadyWatcher.vala"
		_data_->_tmp18_ = g_strdup (_ ("Backup will begin when a network connection becomes available."));
#line 160 "../monitor/ReadyWatcher.vala"
		_g_free0 (_data_->message);
#line 160 "../monitor/ReadyWatcher.vala"
		_data_->message = _data_->_tmp18_;
#line 161 "../monitor/ReadyWatcher.vala"
		_data_->result = FALSE;
#line 161 "../monitor/ReadyWatcher.vala"
		_g_object_unref0 (_data_->network);
#line 161 "../monitor/ReadyWatcher.vala"
		_g_object_unref0 (_data_->backend);
#line 161 "../monitor/ReadyWatcher.vala"
		g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 161 "../monitor/ReadyWatcher.vala"
		if (_data_->_state_ != 0) {
#line 161 "../monitor/ReadyWatcher.vala"
			while (!g_task_get_completed (_data_->_async_result)) {
#line 161 "../monitor/ReadyWatcher.vala"
				g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 866 "ReadyWatcher.c"
			}
		}
#line 161 "../monitor/ReadyWatcher.vala"
		g_object_unref (_data_->_async_result);
#line 161 "../monitor/ReadyWatcher.vala"
		return FALSE;
#line 873 "ReadyWatcher.c"
	} else {
#line 163 "../monitor/ReadyWatcher.vala"
		_data_->_tmp20_ = _data_->backend;
#line 163 "../monitor/ReadyWatcher.vala"
		if (!deja_dup_backend_is_native (_data_->_tmp20_)) {
#line 163 "../monitor/ReadyWatcher.vala"
			_data_->_tmp21_ = _data_->network;
#line 163 "../monitor/ReadyWatcher.vala"
			_data_->_tmp22_ = deja_dup_network_get_metered (_data_->_tmp21_);
#line 163 "../monitor/ReadyWatcher.vala"
			_data_->_tmp23_ = _data_->_tmp22_;
#line 163 "../monitor/ReadyWatcher.vala"
			_data_->_tmp19_ = _data_->_tmp23_;
#line 887 "ReadyWatcher.c"
		} else {
#line 163 "../monitor/ReadyWatcher.vala"
			_data_->_tmp19_ = FALSE;
#line 891 "ReadyWatcher.c"
		}
#line 163 "../monitor/ReadyWatcher.vala"
		if (_data_->_tmp19_) {
#line 164 "../monitor/ReadyWatcher.vala"
			_data_->_tmp24_ = g_strdup ("network-connection.metered");
#line 164 "../monitor/ReadyWatcher.vala"
			_g_free0 (_data_->reason);
#line 164 "../monitor/ReadyWatcher.vala"
			_data_->reason = _data_->_tmp24_;
#line 165 "../monitor/ReadyWatcher.vala"
			_data_->_tmp25_ = g_strdup (_ ("Backup will begin when an unmetered network connection becomes availab" \
"le."));
#line 165 "../monitor/ReadyWatcher.vala"
			_g_free0 (_data_->message);
#line 165 "../monitor/ReadyWatcher.vala"
			_data_->message = _data_->_tmp25_;
#line 166 "../monitor/ReadyWatcher.vala"
			_data_->result = FALSE;
#line 166 "../monitor/ReadyWatcher.vala"
			_g_object_unref0 (_data_->network);
#line 166 "../monitor/ReadyWatcher.vala"
			_g_object_unref0 (_data_->backend);
#line 166 "../monitor/ReadyWatcher.vala"
			g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 166 "../monitor/ReadyWatcher.vala"
			if (_data_->_state_ != 0) {
#line 166 "../monitor/ReadyWatcher.vala"
				while (!g_task_get_completed (_data_->_async_result)) {
#line 166 "../monitor/ReadyWatcher.vala"
					g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 921 "ReadyWatcher.c"
				}
			}
#line 166 "../monitor/ReadyWatcher.vala"
			g_object_unref (_data_->_async_result);
#line 166 "../monitor/ReadyWatcher.vala"
			return FALSE;
#line 928 "ReadyWatcher.c"
		}
	}
#line 169 "../monitor/ReadyWatcher.vala"
	_data_->_tmp26_ = _data_->backend;
#line 169 "../monitor/ReadyWatcher.vala"
	_data_->_tmp27_ = NULL;
#line 169 "../monitor/ReadyWatcher.vala"
	_data_->_tmp28_ = NULL;
#line 169 "../monitor/ReadyWatcher.vala"
	_data_->_state_ = 1;
#line 169 "../monitor/ReadyWatcher.vala"
	deja_dup_backend_is_ready (_data_->_tmp26_, ready_watcher_is_ready_with_reason_ready, _data_);
#line 169 "../monitor/ReadyWatcher.vala"
	return FALSE;
#line 943 "ReadyWatcher.c"
	_state_1:
#line 169 "../monitor/ReadyWatcher.vala"
	_data_->_tmp29_ = deja_dup_backend_is_ready_finish (_data_->_tmp26_, _data_->_res_, &_data_->_tmp27_, &_data_->_tmp28_);
#line 169 "../monitor/ReadyWatcher.vala"
	_g_free0 (_data_->reason);
#line 169 "../monitor/ReadyWatcher.vala"
	_data_->reason = _data_->_tmp27_;
#line 169 "../monitor/ReadyWatcher.vala"
	_g_free0 (_data_->message);
#line 169 "../monitor/ReadyWatcher.vala"
	_data_->message = _data_->_tmp28_;
#line 169 "../monitor/ReadyWatcher.vala"
	_data_->result = _data_->_tmp29_;
#line 169 "../monitor/ReadyWatcher.vala"
	_g_object_unref0 (_data_->network);
#line 169 "../monitor/ReadyWatcher.vala"
	_g_object_unref0 (_data_->backend);
#line 169 "../monitor/ReadyWatcher.vala"
	g_task_return_pointer (_data_->_async_result, _data_, NULL);
#line 169 "../monitor/ReadyWatcher.vala"
	if (_data_->_state_ != 0) {
#line 169 "../monitor/ReadyWatcher.vala"
		while (!g_task_get_completed (_data_->_async_result)) {
#line 169 "../monitor/ReadyWatcher.vala"
			g_main_context_iteration (g_task_get_context (_data_->_async_result), TRUE);
#line 969 "ReadyWatcher.c"
		}
	}
#line 169 "../monitor/ReadyWatcher.vala"
	g_object_unref (_data_->_async_result);
#line 169 "../monitor/ReadyWatcher.vala"
	return FALSE;
#line 976 "ReadyWatcher.c"
}

static void
ready_watcher_volume_added (ReadyWatcher* self)
{
#line 172 "../monitor/ReadyWatcher.vala"
	g_return_if_fail (self != NULL);
#line 174 "../monitor/ReadyWatcher.vala"
	g_signal_emit (self, ready_watcher_signals[READY_WATCHER_MAYBE_READY_SIGNAL], 0, "volume added");
#line 986 "ReadyWatcher.c"
}

static void
ready_watcher_gamemode_changed (ReadyWatcher* self)
{
	GameMode* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 177 "../monitor/ReadyWatcher.vala"
	g_return_if_fail (self != NULL);
#line 179 "../monitor/ReadyWatcher.vala"
	_tmp0_ = self->priv->gamemode;
#line 179 "../monitor/ReadyWatcher.vala"
	_tmp1_ = game_mode_get_enabled (_tmp0_);
#line 179 "../monitor/ReadyWatcher.vala"
	_tmp2_ = _tmp1_;
#line 179 "../monitor/ReadyWatcher.vala"
	if (_tmp2_) {
#line 180 "../monitor/ReadyWatcher.vala"
		g_signal_emit (self, ready_watcher_signals[READY_WATCHER_STOP_AUTO_SIGNAL], 0);
#line 1007 "ReadyWatcher.c"
	}
#line 181 "../monitor/ReadyWatcher.vala"
	g_signal_emit (self, ready_watcher_signals[READY_WATCHER_MAYBE_READY_SIGNAL], 0, "gamemode changed");
#line 1011 "ReadyWatcher.c"
}

static void
ready_watcher_power_saver_changed (ReadyWatcher* self)
{
	GPowerProfileMonitor* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 184 "../monitor/ReadyWatcher.vala"
	g_return_if_fail (self != NULL);
#line 186 "../monitor/ReadyWatcher.vala"
	_tmp0_ = self->priv->power_monitor;
#line 186 "../monitor/ReadyWatcher.vala"
	_tmp1_ = g_power_profile_monitor_get_power_saver_enabled (_tmp0_);
#line 186 "../monitor/ReadyWatcher.vala"
	_tmp2_ = _tmp1_;
#line 186 "../monitor/ReadyWatcher.vala"
	if (_tmp2_) {
#line 187 "../monitor/ReadyWatcher.vala"
		g_signal_emit (self, ready_watcher_signals[READY_WATCHER_STOP_AUTO_SIGNAL], 0);
#line 1032 "ReadyWatcher.c"
	}
#line 188 "../monitor/ReadyWatcher.vala"
	g_signal_emit (self, ready_watcher_signals[READY_WATCHER_MAYBE_READY_SIGNAL], 0, "power saver changed");
#line 1036 "ReadyWatcher.c"
}

static gboolean
__lambda6_ (ReadyWatcher* self)
{
	gboolean result;
#line 204 "../monitor/ReadyWatcher.vala"
	self->priv->netcheck_id = (guint) 0;
#line 205 "../monitor/ReadyWatcher.vala"
	g_signal_emit (self, ready_watcher_signals[READY_WATCHER_MAYBE_READY_SIGNAL], 0, "network status changed");
#line 206 "../monitor/ReadyWatcher.vala"
	result = G_SOURCE_REMOVE;
#line 206 "../monitor/ReadyWatcher.vala"
	return result;
#line 1051 "ReadyWatcher.c"
}

static gboolean
___lambda6__gsource_func (gpointer self)
{
	gboolean result;
	result = __lambda6_ ((ReadyWatcher*) self);
#line 203 "../monitor/ReadyWatcher.vala"
	return result;
#line 1061 "ReadyWatcher.c"
}

static void
ready_watcher_network_changed (ReadyWatcher* self)
{
	gint delay_time = 0;
	gboolean _tmp0_;
#line 191 "../monitor/ReadyWatcher.vala"
	g_return_if_fail (self != NULL);
#line 196 "../monitor/ReadyWatcher.vala"
	if (self->priv->netcheck_id > ((guint) 0)) {
#line 197 "../monitor/ReadyWatcher.vala"
		g_source_remove (self->priv->netcheck_id);
#line 1075 "ReadyWatcher.c"
	}
#line 199 "../monitor/ReadyWatcher.vala"
	g_debug ("ReadyWatcher.vala:199: Network status changed, starting timeout.");
#line 200 "../monitor/ReadyWatcher.vala"
	delay_time = 120;
#line 201 "../monitor/ReadyWatcher.vala"
	_tmp0_ = self->priv->_no_delay;
#line 201 "../monitor/ReadyWatcher.vala"
	if (_tmp0_) {
#line 202 "../monitor/ReadyWatcher.vala"
		delay_time = 0;
#line 1087 "ReadyWatcher.c"
	}
#line 203 "../monitor/ReadyWatcher.vala"
	self->priv->netcheck_id = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) delay_time, ___lambda6__gsource_func, g_object_ref (self), g_object_unref);
#line 1091 "ReadyWatcher.c"
}

gboolean
ready_watcher_get_no_delay (ReadyWatcher* self)
{
	gboolean result;
#line 53 "../monitor/ReadyWatcher.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 53 "../monitor/ReadyWatcher.vala"
	result = self->priv->_no_delay;
#line 53 "../monitor/ReadyWatcher.vala"
	return result;
#line 1104 "ReadyWatcher.c"
}

void
ready_watcher_set_no_delay (ReadyWatcher* self,
                            gboolean value)
{
	gboolean old_value;
#line 53 "../monitor/ReadyWatcher.vala"
	g_return_if_fail (self != NULL);
#line 53 "../monitor/ReadyWatcher.vala"
	old_value = ready_watcher_get_no_delay (self);
#line 53 "../monitor/ReadyWatcher.vala"
	if (old_value != value) {
#line 53 "../monitor/ReadyWatcher.vala"
		self->priv->_no_delay = value;
#line 53 "../monitor/ReadyWatcher.vala"
		g_object_notify_by_pspec ((GObject *) self, ready_watcher_properties[READY_WATCHER_NO_DELAY_PROPERTY]);
#line 1122 "ReadyWatcher.c"
	}
}

static void
_ready_watcher_network_changed_g_object_notify (GObject* _sender,
                                                GParamSpec* pspec,
                                                gpointer self)
{
#line 100 "../monitor/ReadyWatcher.vala"
	ready_watcher_network_changed ((ReadyWatcher*) self);
#line 1133 "ReadyWatcher.c"
}

static void
_ready_watcher_volume_added_g_volume_monitor_volume_added (GVolumeMonitor* _sender,
                                                           GVolume* volume,
                                                           gpointer self)
{
#line 104 "../monitor/ReadyWatcher.vala"
	ready_watcher_volume_added ((ReadyWatcher*) self);
#line 1143 "ReadyWatcher.c"
}

static void
_ready_watcher_gamemode_changed_g_object_notify (GObject* _sender,
                                                 GParamSpec* pspec,
                                                 gpointer self)
{
#line 107 "../monitor/ReadyWatcher.vala"
	ready_watcher_gamemode_changed ((ReadyWatcher*) self);
#line 1153 "ReadyWatcher.c"
}

static void
_ready_watcher_power_saver_changed_g_object_notify (GObject* _sender,
                                                    GParamSpec* pspec,
                                                    gpointer self)
{
#line 110 "../monitor/ReadyWatcher.vala"
	ready_watcher_power_saver_changed ((ReadyWatcher*) self);
#line 1163 "ReadyWatcher.c"
}

static GObject *
ready_watcher_constructor (GType type,
                           guint n_construct_properties,
                           GObjectConstructParam * construct_properties)
{
	GObject * obj;
	GObjectClass * parent_class;
	ReadyWatcher * self;
	DejaDupNetwork* _tmp0_;
	DejaDupNetwork* _tmp1_;
	DejaDupNetwork* _tmp2_;
	DejaDupNetwork* _tmp3_;
	GVolumeMonitor* mon = NULL;
	GVolumeMonitor* _tmp4_;
	GVolumeMonitor* _tmp5_;
	GameMode* _tmp6_;
	GameMode* _tmp7_;
	GPowerProfileMonitor* _tmp8_;
	GPowerProfileMonitor* _tmp9_;
#line 96 "../monitor/ReadyWatcher.vala"
	parent_class = G_OBJECT_CLASS (ready_watcher_parent_class);
#line 96 "../monitor/ReadyWatcher.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 96 "../monitor/ReadyWatcher.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_READY_WATCHER, ReadyWatcher);
#line 98 "../monitor/ReadyWatcher.vala"
	ready_watcher_reset_reasons (self);
#line 100 "../monitor/ReadyWatcher.vala"
	_tmp0_ = deja_dup_network_get ();
#line 100 "../monitor/ReadyWatcher.vala"
	_tmp1_ = _tmp0_;
#line 100 "../monitor/ReadyWatcher.vala"
	g_signal_connect_object ((GObject*) _tmp1_, "notify::connected", (GCallback) _ready_watcher_network_changed_g_object_notify, self, 0);
#line 100 "../monitor/ReadyWatcher.vala"
	_g_object_unref0 (_tmp1_);
#line 101 "../monitor/ReadyWatcher.vala"
	_tmp2_ = deja_dup_network_get ();
#line 101 "../monitor/ReadyWatcher.vala"
	_tmp3_ = _tmp2_;
#line 101 "../monitor/ReadyWatcher.vala"
	g_signal_connect_object ((GObject*) _tmp3_, "notify::metered", (GCallback) _ready_watcher_network_changed_g_object_notify, self, 0);
#line 101 "../monitor/ReadyWatcher.vala"
	_g_object_unref0 (_tmp3_);
#line 103 "../monitor/ReadyWatcher.vala"
	_tmp4_ = deja_dup_get_volume_monitor ();
#line 103 "../monitor/ReadyWatcher.vala"
	mon = _tmp4_;
#line 104 "../monitor/ReadyWatcher.vala"
	_tmp5_ = mon;
#line 104 "../monitor/ReadyWatcher.vala"
	g_signal_connect_object (_tmp5_, "volume-added", (GCallback) _ready_watcher_volume_added_g_volume_monitor_volume_added, self, 0);
#line 106 "../monitor/ReadyWatcher.vala"
	_tmp6_ = game_mode_new ();
#line 106 "../monitor/ReadyWatcher.vala"
	_g_object_unref0 (self->priv->gamemode);
#line 106 "../monitor/ReadyWatcher.vala"
	self->priv->gamemode = _tmp6_;
#line 107 "../monitor/ReadyWatcher.vala"
	_tmp7_ = self->priv->gamemode;
#line 107 "../monitor/ReadyWatcher.vala"
	g_signal_connect_object ((GObject*) _tmp7_, "notify::enabled", (GCallback) _ready_watcher_gamemode_changed_g_object_notify, self, 0);
#line 109 "../monitor/ReadyWatcher.vala"
	_tmp8_ = g_power_profile_monitor_dup_default ();
#line 109 "../monitor/ReadyWatcher.vala"
	_g_object_unref0 (self->priv->power_monitor);
#line 109 "../monitor/ReadyWatcher.vala"
	self->priv->power_monitor = _tmp8_;
#line 110 "../monitor/ReadyWatcher.vala"
	_tmp9_ = self->priv->power_monitor;
#line 110 "../monitor/ReadyWatcher.vala"
	g_signal_connect_object ((GObject*) _tmp9_, "notify::power-saver-enabled", (GCallback) _ready_watcher_power_saver_changed_g_object_notify, self, 0);
#line 96 "../monitor/ReadyWatcher.vala"
	_g_object_unref0 (mon);
#line 96 "../monitor/ReadyWatcher.vala"
	return obj;
#line 1241 "ReadyWatcher.c"
}

static void
ready_watcher_class_init (ReadyWatcherClass * klass,
                          gpointer klass_data)
{
#line 45 "../monitor/ReadyWatcher.vala"
	ready_watcher_parent_class = g_type_class_peek_parent (klass);
#line 45 "../monitor/ReadyWatcher.vala"
	g_type_class_adjust_private_offset (klass, &ReadyWatcher_private_offset);
#line 45 "../monitor/ReadyWatcher.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_ready_watcher_get_property;
#line 45 "../monitor/ReadyWatcher.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_ready_watcher_set_property;
#line 45 "../monitor/ReadyWatcher.vala"
	G_OBJECT_CLASS (klass)->constructor = ready_watcher_constructor;
#line 45 "../monitor/ReadyWatcher.vala"
	G_OBJECT_CLASS (klass)->finalize = ready_watcher_finalize;
#line 45 "../monitor/ReadyWatcher.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), READY_WATCHER_NO_DELAY_PROPERTY, ready_watcher_properties[READY_WATCHER_NO_DELAY_PROPERTY] = g_param_spec_boolean ("no-delay", "no-delay", "no-delay", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 45 "../monitor/ReadyWatcher.vala"
	ready_watcher_signals[READY_WATCHER_MAYBE_READY_SIGNAL] = g_signal_new ("maybe-ready", TYPE_READY_WATCHER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
#line 45 "../monitor/ReadyWatcher.vala"
	ready_watcher_signals[READY_WATCHER_STOP_AUTO_SIGNAL] = g_signal_new ("stop-auto", TYPE_READY_WATCHER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 1266 "ReadyWatcher.c"
}

static void
ready_watcher_instance_init (ReadyWatcher * self,
                             gpointer klass)
{
#line 45 "../monitor/ReadyWatcher.vala"
	self->priv = ready_watcher_get_instance_private (self);
#line 91 "../monitor/ReadyWatcher.vala"
	self->priv->netcheck_id = (guint) 0;
#line 92 "../monitor/ReadyWatcher.vala"
	self->priv->unready_reasons = NULL;
#line 93 "../monitor/ReadyWatcher.vala"
	self->priv->gamemode = NULL;
#line 94 "../monitor/ReadyWatcher.vala"
	self->priv->power_monitor = NULL;
#line 1283 "ReadyWatcher.c"
}

static void
ready_watcher_finalize (GObject * obj)
{
	ReadyWatcher * self;
#line 45 "../monitor/ReadyWatcher.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_READY_WATCHER, ReadyWatcher);
#line 115 "../monitor/ReadyWatcher.vala"
	if (self->priv->netcheck_id > ((guint) 0)) {
#line 116 "../monitor/ReadyWatcher.vala"
		g_source_remove (self->priv->netcheck_id);
#line 117 "../monitor/ReadyWatcher.vala"
		self->priv->netcheck_id = (guint) 0;
#line 1298 "ReadyWatcher.c"
	}
#line 92 "../monitor/ReadyWatcher.vala"
	_g_hash_table_unref0 (self->priv->unready_reasons);
#line 93 "../monitor/ReadyWatcher.vala"
	_g_object_unref0 (self->priv->gamemode);
#line 94 "../monitor/ReadyWatcher.vala"
	_g_object_unref0 (self->priv->power_monitor);
#line 45 "../monitor/ReadyWatcher.vala"
	G_OBJECT_CLASS (ready_watcher_parent_class)->finalize (obj);
#line 1308 "ReadyWatcher.c"
}

 G_GNUC_NO_INLINE static GType
ready_watcher_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (ReadyWatcherClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) ready_watcher_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ReadyWatcher), 0, (GInstanceInitFunc) ready_watcher_instance_init, NULL };
	GType ready_watcher_type_id;
	ready_watcher_type_id = g_type_register_static (G_TYPE_OBJECT, "ReadyWatcher", &g_define_type_info, 0);
	ReadyWatcher_private_offset = g_type_add_instance_private (ready_watcher_type_id, sizeof (ReadyWatcherPrivate));
	return ready_watcher_type_id;
}

GType
ready_watcher_get_type (void)
{
	static gsize ready_watcher_type_id__once = 0;
	if (g_once_init_enter (&ready_watcher_type_id__once)) {
		GType ready_watcher_type_id;
		ready_watcher_type_id = ready_watcher_get_type_once ();
		g_once_init_leave (&ready_watcher_type_id__once, ready_watcher_type_id);
	}
	return ready_watcher_type_id__once;
}

static void
_vala_ready_watcher_get_property (GObject * object,
                                  guint property_id,
                                  GValue * value,
                                  GParamSpec * pspec)
{
	ReadyWatcher * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_READY_WATCHER, ReadyWatcher);
#line 45 "../monitor/ReadyWatcher.vala"
	switch (property_id) {
#line 45 "../monitor/ReadyWatcher.vala"
		case READY_WATCHER_NO_DELAY_PROPERTY:
#line 45 "../monitor/ReadyWatcher.vala"
		g_value_set_boolean (value, ready_watcher_get_no_delay (self));
#line 45 "../monitor/ReadyWatcher.vala"
		break;
#line 1349 "ReadyWatcher.c"
		default:
#line 45 "../monitor/ReadyWatcher.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 45 "../monitor/ReadyWatcher.vala"
		break;
#line 1355 "ReadyWatcher.c"
	}
}

static void
_vala_ready_watcher_set_property (GObject * object,
                                  guint property_id,
                                  const GValue * value,
                                  GParamSpec * pspec)
{
	ReadyWatcher * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TYPE_READY_WATCHER, ReadyWatcher);
#line 45 "../monitor/ReadyWatcher.vala"
	switch (property_id) {
#line 45 "../monitor/ReadyWatcher.vala"
		case READY_WATCHER_NO_DELAY_PROPERTY:
#line 45 "../monitor/ReadyWatcher.vala"
		ready_watcher_set_no_delay (self, g_value_get_boolean (value));
#line 45 "../monitor/ReadyWatcher.vala"
		break;
#line 1375 "ReadyWatcher.c"
		default:
#line 45 "../monitor/ReadyWatcher.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 45 "../monitor/ReadyWatcher.vala"
		break;
#line 1381 "ReadyWatcher.c"
	}
}

static void
_vala_array_destroy (gpointer array,
                     gssize array_length,
                     GDestroyNotify destroy_func)
{
	if ((array != NULL) && (destroy_func != NULL)) {
		gssize i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}

static void
_vala_array_free (gpointer array,
                  gssize array_length,
                  GDestroyNotify destroy_func)
{
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}

static gssize
_vala_array_length (gpointer array)
{
	gssize length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}

